@@ -1,12 +1,31 @@
 package Image::Info::PNG;
 
-# Copyright 1999-200, Gisle Aas.
+# Copyright 1999-2000, Gisle Aas.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
+=begin register
+
+MAGIC: /^\x89PNG\x0d\x0a\x1a\x0a/
+
+Information from IHDR, PLTE, gAMA, pHYs, tEXt, tIME chunks are
+extracted.  The sequence of chunks are also given by the C<PNG_Chunks>
+key.
+
+=end register
+
+=cut
+
 use strict;
 
+# Test for Compress::Zlib (for reading zTXt chunks)
+my $have_zlib = 0;
+eval {
+    require Compress::Zlib;
+    $have_zlib++;
+};
+
 sub my_read
 {
     my($source, $len) = @_;
@@ -70,7 +89,7 @@ sub process_file
 
 	    $info->push_info(0, "width", $w);
 	    $info->push_info(0, "height", $h);
-	    $info->push_info(0, "sample_format", "U$depth");
+	    $info->push_info(0, "SampleFormat", "U$depth");
 	    $info->push_info(0, "color_type", $ctype);
 
 	    $info->push_info(0, "Compression", $compression);
@@ -84,7 +103,7 @@ sub process_file
 		push(@table, sprintf("#%02x%02x%02x",
 				     unpack("C3", substr($data, 0, 3, ""))));
 	    }
-	    $info->push_info(0, "RGB_Palette" => \@table);
+	    $info->push_info(0, "ColorPalette" => \@table);
 	}
 	elsif ($type eq "gAMA" && $len == 4) {
 	    $info->push_info(0, "Gamma", unpack("N", $data)/100_000);
@@ -101,8 +120,12 @@ sub process_file
 	    }
 	    $res = ($res_x == $res_y) ? $res_x : "$res_x/$res_y";
 	    if ($unit) {
-		$unit = "dpm" if $unit == 1;
-		$res .= " $unit";
+		if ($unit == 1) {
+		    $res .= " dpm";
+		}
+		else {
+		    $res .= " png-unit-$unit";
+		}
 	    }
 	    $info->push_info(0, "resolution" => $res)
 	}
@@ -112,6 +135,15 @@ sub process_file
 	    # other key we might generate
 	    $info->push_info(0, $key, $val);
 	}
+	elsif ($type eq "zTXt" && $have_zlib) {
+		my($key, $val) = split(/\0/, $data, 2);
+		my($method,$ctext) = split(//, $val, 2);
+		if ($method eq "\0") {
+		    $info->push_info(0, $key, Compress::Zlib::uncompress($ctext));
+		} else {
+		    $info->push_info(0, "Chunk-$type" => $data);
+		}
+	}
 	elsif ($type eq "tIME" && $len == 7) {
 	    $info->push_info(0, "LastModificationTime",
 			     sprintf("%04d-%02d-%02d %02d:%02d:%02d",
@@ -129,6 +161,10 @@ sub process_file
     }
 
     $info->push_info(0, "PNG_Chunks", @chunks);
+
+    unless ($info->get_info(0, "resolution")) {
+	$info->push_info(0, "resolution", "1/1");
+    }
 }
 
 1;
